package
module
Version:
v1.0.0
Opens a new window with list of versions in this module.
Published: May 26, 2024
License: MIT
Opens a new window with license information.
Imports: 1
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
func JxMatting(appID, sdkKey, activeKey string) (err error)
测试接口
func JxTest(appID, sdkKey, activeKey string) (err error)
测试接口
type EngineError struct {
Code int
Text string
}
EngineError SDK错误码
Source Files
¶
Click to show internal directories.
Click to hide internal directories.